pub enum SnapshotVerifyMode {
None,
Normal,
Strict,
}Variants
None
verification of both db state and downloaded checkpoints are skipped. This is the fastest mode, but is unsafe, and thus should only be used if you fully trust the source for both the snapshot and the checkpoint archive.
Normal
verify snapshot state during download, but no post-restore db verification. Checkpoint verification is performed.
Strict
In ADDITION to the behavior of --verify normal, verify db state post-restore
against the end of epoch state root commitment.